@@ -18,8 +18,11 @@ if [ ! -f tilix ]; then
 fi
 
 # Check availability of required commands
-COMMANDS="install glib-compile-schemas glib-compile-resources msgfmt desktop-file-validate xdg-desktop-menu gtk-update-icon-cache"
-PACKAGES="coreutils glib2 glib2 gettext desktop-file-utils xdg-utils gtk-update-icon-cache"
+COMMANDS="install glib-compile-schemas glib-compile-resources msgfmt desktop-file-validate gtk-update-icon-cache"
+if [ "$PREFIX" = '/usr' ] || [ "$PREFIX" = "/usr/local" ]; then
+    COMMANDS="$COMMANDS xdg-desktop-menu"
+fi
+PACKAGES="coreutils glib2 glib2 gettext desktop-file-utils gtk-update-icon-cache xdg-utils"
 i=0
 for COMMAND in $COMMANDS; do
     type $COMMAND >/dev/null 2>&1 || {
@@ -44,26 +47,26 @@ install -d ${PREFIX}/share/glib-2.0/schemas
 install -m 644 data/gsettings/com.gexperts.Tilix.gschema.xml ${PREFIX}/share/glib-2.0/schemas/
 glib-compile-schemas ${PREFIX}/share/glib-2.0/schemas/
 
-export TERMINIX_SHARE=${PREFIX}/share/tilix
+export TILIX_SHARE=${PREFIX}/share/tilix
 
-install -d ${TERMINIX_SHARE}/resources ${TERMINIX_SHARE}/schemes ${TERMINIX_SHARE}/scripts
+install -d ${TILIX_SHARE}/resources ${TILIX_SHARE}/schemes ${TILIX_SHARE}/scripts
 
 # Copy and compile icons
 cd data/resources
 
 echo "Building and copy resources..."
 glib-compile-resources tilix.gresource.xml
-install -m 644 tilix.gresource ${TERMINIX_SHARE}/resources/
+install -m 644 tilix.gresource ${TILIX_SHARE}/resources/
 
 cd ../..
 
 # Copy shell integration script
 echo "Copying scripts..."
-install -m 755 data/scripts/* ${TERMINIX_SHARE}/scripts/
+install -m 755 data/scripts/* ${TILIX_SHARE}/scripts/
 
 # Copy color schemes
 echo "Copying color schemes..."
-install -m 644 data/schemes/* ${TERMINIX_SHARE}/schemes/
+install -m 644 data/schemes/* ${TILIX_SHARE}/schemes/
 
 # Create/Update LINGUAS file
 find po -name "*\.po" -printf "%f\\n" | sed "s/\.po//g" | sort > po/LINGUAS
